@@ -8,23 +8,23 @@
 /* Machine byte-order */
 #define Q_BIG_ENDIAN 4321
 #define Q_LITTLE_ENDIAN 1234
-#define QT_BUILD_KEY "i386 openbsd g++-4 full-config"
-#define QT_BUILD_KEY_COMPAT "i386 OpenBSD g++-4 full-config"
+#define QT_BUILD_KEY "generic openbsd g++-4 full-config"
+#define QT_BUILD_KEY_COMPAT "sparc64 OpenBSD g++-4 full-config"
 
 #ifdef QT_BOOTSTRAPPED
-#define Q_BYTE_ORDER Q_LITTLE_ENDIAN
+#define Q_BYTE_ORDER Q_BIG_ENDIAN
 #else
-#define Q_BYTE_ORDER Q_LITTLE_ENDIAN
+#define Q_BYTE_ORDER Q_BIG_ENDIAN
 #endif
 /* Machine Architecture */
 #ifndef QT_BOOTSTRAPPED
-# define QT_ARCH_I386
+# define QT_ARCH_GENERIC
 #else
-# define QT_ARCH_I386
+# define QT_ARCH_GENERIC
 #endif
 /* Compile time features */
 #define QT_LARGEFILE_SUPPORT 64
-#define QT_POINTER_SIZE 4
+#define QT_POINTER_SIZE 8
 
 #ifndef QT_BOOTSTRAPPED
 
